@@ -17,9 +17,17 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>
 
 """Some tools for working with Gentoo.
+ 
 
-Usage: babtools_gentoo.py cmd [OPTIONS]
-        or: babtools_gentoo.py --help
+Usage: 
+ - babtools_gentoo.py cmd [OPTIONS]
+   
+   for default usage, or 
+   
+ - babtools_gentoo.py --help
+   
+   for getting help
+ 
 
 Avaible commands: 
  - ebuild_to_local CP
@@ -29,6 +37,7 @@ Avaible commands:
  - ebuild_download_to_local CP URL
   
    Download an ebuild from bugs.gentoo.org to the local portage tree.    
+ 
 
 Examples: 
  - sudo babtools_gentoo.py ebuild_to_local dev-lang/python
